# lubricate

Lubricate helps you decrease friction when stuck at starting a project, no
matter if it's a scientific analysis or a Python package. It will initialise a
ready-to-use project structure with decent defaults.

## To get started:

    pip install lubricate
    lubricate new analysis the_analysis
